Tools for converting Keras models for use with other ML frameworks.

[![Build Status](https://travis-ci.org/triagemd/model-converters.svg?branch=master)](https://travis-ci.org/triagemd/model-converters)
[![PyPI version](https://badge.fury.io/py/model-converters.svg)](https://badge.fury.io/py/model-converters)
[![codecov](https://codecov.io/gh/triagemd/model-converters/branch/master/graph/badge.svg)](https://codecov.io/gh/triagemd/model-converters)

# Getting started

To install: `pip install --upgrade model-converters`

To use: `keras_to_tensorflow <hdf5_model_file> <output_dir> (<feature_layer>)`
